==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/vo/ReceivingaddressVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收货地址
 * 
 * @author generator
 * 
 */
public class ReceivingaddressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private String receivingAddressName; // 收货地址名称
    private String receivingAddress; // 收货地址
    private String longitude; // 收货地址经度
    private String dimension; // 收货地址纬度
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String billCode; // 单据编号

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getReceivingAddressName() {
        return receivingAddressName;
    }

    public void setReceivingAddressName(String receivingAddressName) {
        this.receivingAddressName = receivingAddressName;
    }
    public String getReceivingAddress() {
        return receivingAddress;
    }

    public void setReceivingAddress(String receivingAddress) {
        this.receivingAddress = receivingAddress;
    }
    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }
    public String getDimension() {
        return dimension;
    }

    public void setDimension(String dimension) {
        this.dimension = dimension;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220718.141214-167-sources.jar: com/ejianc/business/purchasingmanagement/vo/ReceivingaddressVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收货地址
 * 
 * @author generator
 * 
 */
public class ReceivingaddressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private String receivingAddressName; // 收货地址名称
    private String receivingAddress; // 收货地址
    private String longitude; // 收货地址经度
    private String dimension; // 收货地址纬度
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String billCode; // 单据编号
    private  Integer defaultStatus;//默认地址
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getDefaultStatus() {
        return defaultStatus;
    }

    public void setDefaultStatus(Integer defaultStatus) {
        this.defaultStatus = defaultStatus;
    }

    public String getReceivingAddressName() {
        return receivingAddressName;
    }


    public void setReceivingAddressName(String receivingAddressName) {
        this.receivingAddressName = receivingAddressName;
    }
    public String getReceivingAddress() {
        return receivingAddress;
    }

    public void setReceivingAddress(String receivingAddress) {
        this.receivingAddress = receivingAddress;
    }
    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }
    public String getDimension() {
        return dimension;
    }

    public void setDimension(String dimension) {
        this.dimension = dimension;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
